@@ -1,5 +1,5 @@
 Clazz.declarePackage ("J.adapter.readers.molxyz");
-Clazz.load (["J.adapter.smarter.AtomSetCollectionReader"], "J.adapter.readers.molxyz.MolReader", ["java.lang.Exception", "java.util.Hashtable", "JU.PT", "J.adapter.smarter.Atom", "J.api.JmolAdapter", "JU.Logger"], function () {
+Clazz.load (["J.adapter.smarter.AtomSetCollectionReader"], "J.adapter.readers.molxyz.MolReader", ["java.lang.Exception", "java.util.Hashtable", "JU.PT", "J.adapter.smarter.Atom", "J.api.JmolAdapter", "JU.Elements", "$.Logger"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.optimize2D = false;
 this.haveAtomSerials = false;
@@ -135,13 +135,40 @@ if (this.haveAtomSerials) this.asc.addNewBondFromNames (iAtom1, iAtom2, order);
 }
 var atoms = this.asc.atoms;
 var molData =  new java.util.Hashtable ();
-var haveData = false;
 this.rd ();
 while (this.line != null && this.line.indexOf ("$$$$") != 0) {
-if (this.line.indexOf (">") != 0) {
-this.rd ();
+if (this.line.indexOf (">") == 0) {
+this.readMolData (molData);
 continue;
-}var dataName = JU.PT.trim (this.line, "> <").toLowerCase ();
+}if (this.line.startsWith ("M  ISO")) {
+this.readIsotopes ();
+continue;
+}this.rd ();
+}
+if (!molData.isEmpty ()) this.asc.setModelInfoForSet ("molData", molData, this.asc.iSet);
+}, "~N,~N");
+Clazz.defineMethod (c$, "readIsotopes", 
+ function () {
+var n = this.parseIntAt (this.line, 6);
+try {
+for (var i = 0, pt = 9; i < n; i++) {
+var ipt = this.parseIntAt (this.line, pt) - 1;
+var atom = this.asc.atoms[ipt];
+var ss = atom.getElementSymbol ();
+var iso = this.parseIntAt (this.line, pt + 4) + JU.Elements.getNaturalIsotope (J.api.JmolAdapter.getElementNumber (ss));
+pt += 8;
+var s = atom.elementSymbol = "" + iso + atom.elementSymbol;
+System.out.println (s);
+atom.elementSymbol = s;
+}
+} catch (e) {
+}
+this.rd ();
+});
+Clazz.defineMethod (c$, "readMolData", 
+ function (molData) {
+var atoms = this.asc.atoms;
+var dataName = JU.PT.trim (this.line, "> <").toLowerCase ();
 var data = "";
 var fdata = null;
 while (this.rd () != null && this.line.indexOf ("$$$$") != 0 && this.line.indexOf (">") != 0) {
@@ -150,7 +177,6 @@ continue;
 }
 data = JU.PT.trim (data, "\n");
 JU.Logger.info (dataName + ":" + data.$replace ('\n', '|'));
-haveData = true;
 molData.put (dataName, data);
 if (dataName.toUpperCase ().contains ("_PARTIAL_CHARGES")) {
 try {
@@ -172,9 +198,7 @@ return;
 throw e;
 }
 }
-}}
-if (haveData) this.asc.setModelInfoForSet ("molData", molData, this.asc.iSet);
-}, "~N,~N");
+}}, "java.util.Map");
 Clazz.defineMethod (c$, "addMolAtom", 
 function (iAtom, isotope, elementSymbol, charge, x, y, z) {
 switch (isotope) {
