@@ -14,6 +14,7 @@ this.basePt = null;
 this.backbonePt = null;
 this.baseScreen = null;
 this.backboneScreen = null;
+this.ptTemp = null;
 this.vwr = null;
 this.tm = null;
 this.g3d = null;
@@ -181,8 +182,10 @@ for (var j = 8; --j >= 0; ) box[j] =  new JU.P3 ();
 
 g.dssrBox = box;
 }var uc = this.vwr.getSymTemp ().getUnitCell (oxyz, false, null);
-uc.toFractional (oxyz[0], true);
-uc.setOffsetPt (JU.P3.new3 (oxyz[0].x - 2.25, oxyz[0].y + 5, oxyz[0].z - this.blockHeight / 2));
+if (this.ptTemp == null) this.ptTemp =  new JU.P3 ();
+this.ptTemp.setT (oxyz[0]);
+uc.toFractional (this.ptTemp, true);
+uc.setOffsetPt (JU.P3.new3 (this.ptTemp.x - 2.25, this.ptTemp.y + 5, this.ptTemp.z - this.blockHeight / 2));
 var x = 4.5;
 var y = (isPurine ? -4.5 : -3.0);
 var z = this.blockHeight;
