@@ -1,5 +1,5 @@
 Clazz.declarePackage ("JM");
-Clazz.load (["JU.Node", "$.Point3fi", "J.c.PAL"], "JM.Atom", ["java.lang.Float", "JU.BS", "$.CU", "$.P3", "$.PT", "$.SB", "J.atomdata.RadiusData", "J.c.VDW", "JM.Group", "JU.C", "$.Elements"], function () {
+Clazz.load (["JU.Node", "$.Point3fi", "J.c.PAL"], "JM.Atom", ["java.lang.Float", "JU.BS", "$.CU", "$.P3", "$.PT", "$.SB", "J.atomdata.RadiusData", "J.c.VDW", "JM.Group", "JU.C", "$.Elements", "JV.JC"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.altloc = '\0';
 this.atomID = 0;
@@ -462,6 +462,10 @@ Clazz.defineMethod (c$, "getFractionalCoord",
 pt = this.getFractionalCoordPt (fixJavaFloat, ignoreOffset, pt);
 return (ch == 'X' ? pt.x : ch == 'Y' ? pt.y : pt.z);
 }, "~B,~S,~B,JU.P3");
+Clazz.overrideMethod (c$, "getXYZ", 
+function () {
+return this;
+});
 Clazz.defineMethod (c$, "getFractionalCoordPt", 
 function (fixJavaFloat, ignoreOffset, pt) {
 var c = this.getUnitCell ();
@@ -926,7 +930,8 @@ return this.group.chain.model.ms.getVibCoord (this.i, ch);
 }, "~S");
 Clazz.overrideMethod (c$, "getNominalMass", 
 function () {
-return Math.round (this.getMass ());
+var mass = this.getIsotopeNumber ();
+return (mass > 0 ? mass : JU.Elements.getNaturalIsotope (this.getElementNumber ()));
 });
 Clazz.defineMethod (c$, "getMass", 
  function () {
@@ -991,24 +996,7 @@ var flags = (this.formalChargeAndFlags & 4080) >> 4;
 if (flags == 0 && this.atomicAndIsotopeNumber > 1 && doCalculate) {
 flags = this.group.chain.model.ms.getAtomCIPChirality (this);
 this.formalChargeAndFlags |= ((flags == 0 ? 3 : flags) << 4);
-}switch (flags) {
-case 8:
-return "Z";
-case 16:
-return "E";
-case 1:
-return "R";
-case 2:
-return "S";
-case 5:
-return "(r)";
-case 6:
-return "(s)";
-case 7:
-return "(*)";
-default:
-return "";
-}
+}return (JV.JC.getCIPChiralityName (flags));
 }, "~B");
 Clazz.overrideMethod (c$, "setCIPChirality", 
 function (c) {
@@ -1098,11 +1086,6 @@ Clazz.defineStatics (c$,
 "VIBRATION_VECTOR_FLAG", 1,
 "IS_HETERO_FLAG", 2,
 "CIP_CHIRALITY_OFFSET", 4,
-"CIP_CHIRALITY_R_FLAG", 1,
-"CIP_CHIRALITY_S_FLAG", 2,
-"CIP_CHIRALITY_PSEUDO_FLAG", 4,
-"CIP_CHIRALITY_Z_FLAG", 8,
-"CIP_CHIRALITY_E_FLAG", 0x10,
 "CIP_CHIRALITY_MASK", 0xFF0,
 "FLAG_MASK", 0xF);
 });
