@@ -135,6 +135,11 @@ if (chain.chainID == chainID) return chain;
 }
 return null;
 }, "~N");
+Clazz.defineMethod (c$, "resetDSSR", 
+function (totally) {
+this.dssrCache = null;
+if (totally) this.auxiliaryInfo.remove ("dssr");
+}, "~B");
 Clazz.defineMethod (c$, "fixIndices", 
 function (modelIndex, nAtomsDeleted, bsDeleted) {
 this.fixIndicesM (modelIndex, nAtomsDeleted, bsDeleted);
