@@ -1,7 +1,6 @@
 Clazz.declarePackage ("JS");
-Clazz.load (["JU.Lst", "$.V3"], "JS.CIPChirality", ["java.util.Arrays", "$.Hashtable", "JU.BS", "$.Measure", "$.P3", "$.P4", "$.PT", "JU.BSUtil", "$.Logger"], function () {
+Clazz.load (["JU.Lst", "$.V3"], "JS.CIPChirality", ["java.util.Arrays", "$.Hashtable", "JU.BS", "$.Measure", "$.P3", "$.P4", "$.PT", "JU.BSUtil", "$.Logger", "JV.JC"], function () {
 c$ = Clazz.decorateAsClass (function () {
-this.vwr = null;
 this.ptID = 0;
 this.root = null;
 this.currentRule = 1;
@@ -30,11 +29,6 @@ return "" + this.currentRule;
 Clazz.makeConstructor (c$, 
 function () {
 });
-Clazz.defineMethod (c$, "setViewer", 
-function (vwr) {
-this.vwr = vwr;
-return this;
-}, "JV.Viewer");
 Clazz.defineMethod (c$, "init", 
  function () {
 this.ptID = 0;
@@ -42,7 +36,7 @@ this.nPriorityMax = this.maxRingSize = 0;
 this.lstSmallRings.clear ();
 });
 Clazz.defineMethod (c$, "getChiralityForAtoms", 
-function (atoms, bsAtoms) {
+function (atoms, bsAtoms, bsAtropisomeric) {
 if (bsAtoms.isEmpty ()) return;
 this.init ();
 var bsToDo = JU.BSUtil.copy (bsAtoms);
@@ -58,7 +52,7 @@ atom.setCIPChirality (this.getAtomChiralityLimited (atom, null, null, 3));
 var lstEZ =  new JU.Lst ();
 if (haveAlkenes) {
 this.getSmallRings (atoms[bsAtoms.nextSetBit (0)]);
-for (var i = bsToDo.nextSetBit (0); i >= 0; i = bsToDo.nextSetBit (i + 1)) this.getAtomBondChirality (atoms[i], false, 3, lstEZ, bsToDo);
+for (var i = bsToDo.nextSetBit (0); i >= 0; i = bsToDo.nextSetBit (i + 1)) this.getAtomBondChirality (atoms[i], false, 3, lstEZ, bsToDo, bsAtropisomeric);
 
 }for (var i = bsToDo.nextSetBit (0); i >= 0; i = bsToDo.nextSetBit (i + 1)) {
 var a = atoms[i];
@@ -66,10 +60,10 @@ a.setCIPChirality (0);
 a.setCIPChirality (this.getAtomChiralityLimited (a, null, null, 5));
 }
 if (haveAlkenes) {
-for (var i = bsToDo.nextSetBit (0); i >= 0; i = bsToDo.nextSetBit (i + 1)) this.getAtomBondChirality (atoms[i], false, 5, lstEZ, bsToDo);
+for (var i = bsToDo.nextSetBit (0); i >= 0; i = bsToDo.nextSetBit (i + 1)) this.getAtomBondChirality (atoms[i], false, 5, lstEZ, bsToDo, bsAtropisomeric);
 
 }if (this.lstSmallRings.size () > 0 && lstEZ.size () > 0) this.clearSmallRingEZ (atoms, lstEZ);
-}, "~A,JU.BS");
+}, "~A,JU.BS,JU.BS");
 Clazz.defineMethod (c$, "preFilterAtomList", 
  function (atoms, bsToDo) {
 var haveAlkenes = false;
@@ -77,7 +71,7 @@ for (var i = bsToDo.nextSetBit (0); i >= 0; i = bsToDo.nextSetBit (i + 1)) {
 if (!this.couldBeChiralAtom (atoms[i])) {
 bsToDo.clear (i);
 continue;
-}if (!haveAlkenes && this.couldBeEZ (atoms[i], null)) haveAlkenes = true;
+}if (!haveAlkenes && this.couldBeChiralAlkene (atoms[i], null) != -1) haveAlkenes = true;
 }
 return haveAlkenes;
 }, "~A,JU.BS");
@@ -121,28 +115,28 @@ return false;
 var d = this.getTrigonality (a, this.vNorm);
 return ((Math.abs (d) < 0.2) == mustBePlanar);
 }, "JU.Node");
-Clazz.defineMethod (c$, "couldBeEZ", 
+Clazz.defineMethod (c$, "couldBeChiralAlkene", 
  function (a, b) {
 switch (a.getCovalentBondCount ()) {
 default:
-return false;
+return -1;
 case 2:
-if (a.getElementNumber () != 7) return false;
+if (a.getElementNumber () != 7) return -1;
 break;
 case 3:
-if (!this.isFirstRow (a)) return false;
+if (!this.isFirstRow (a)) return -1;
 break;
 }
 var bonds = a.getEdges ();
 var n = 0;
 for (var i = bonds.length; --i >= 0; ) if (bonds[i].getCovalentOrder () == 2) {
-if (++n > 1) return false;
+if (++n > 1) return -3;
 var other = bonds[i].getOtherAtomNode (a);
-if (!this.isFirstRow (other)) return false;
+if (!this.isFirstRow (other)) return -1;
 if (b != null && (other !== b || b.getCovalentBondCount () == 1)) {
-return false;
+return -1;
 }}
-return true;
+return -2;
 }, "JU.Node,JU.Node");
 Clazz.defineMethod (c$, "isFirstRow", 
 function (a) {
@@ -153,7 +147,7 @@ Clazz.defineMethod (c$, "getSmallRings",
  function (atom) {
 this.lstSmallRings =  new JU.Lst ();
 this.htPathPoints =  new java.util.Hashtable ();
-this.root = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null, atom, null, false, false);
+this.root = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null).create (atom, null, false, false);
 this.addSmallRings (this.root);
 }, "JU.Node");
 Clazz.defineMethod (c$, "addSmallRings", 
@@ -200,20 +194,48 @@ Clazz.defineMethod (c$, "getBondChirality",
 function (bond) {
 this.init ();
 this.getSmallRings (bond.getOtherAtomNode (null));
-return this.getBondChiralityLimited (bond, 3);
+return (bond.getCovalentOrder () == 2 ? this.getBondChiralityLimited (bond, null, 3) : 0);
 }, "JU.Edge");
 Clazz.defineMethod (c$, "getAtomBondChirality", 
- function (atom, allBonds, ruleMax, lstEZ, bsToDo) {
-var bonds = atom.getEdges ();
+ function (atom, allBonds, ruleMax, lstEZ, bsToDo, bsAtrop) {
 var index = atom.getIndex ();
+var bonds = atom.getEdges ();
+if (bsAtrop.get (index)) {
 for (var j = bonds.length; --j >= 0; ) {
+var atom1 = bonds[j].getOtherAtomNode (atom);
+var index1 = atom1.getIndex ();
+if (!allBonds && index1 < index || !bsAtrop.get (index1)) continue;
+this.getAxialOrEZChirality (atom, atom1, true, ruleMax);
+break;
+}
+return;
+}for (var j = bonds.length; --j >= 0; ) {
 var bond = bonds[j];
 if (bond.getCovalentOrder () == 2) {
-var index2 = bond.getOtherAtomNode (atom).getIndex ();
-if ((allBonds || index2 > index) && this.getBondChiralityLimited (bond, ruleMax) != 0) {
+var atom2 = this.getLastCumuleneAtom (bond, atom, null);
+var index2 = atom2.getIndex ();
+if ((allBonds || index2 > index) && this.getBondChiralityLimited (bond, atom, ruleMax) != 0) {
 lstEZ.addLast ( Clazz.newIntArray (-1, [index, index2]));
 }}}
-}, "JU.Node,~B,~N,JU.Lst,JU.BS");
+}, "JU.Node,~B,~N,JU.Lst,JU.BS,JU.BS");
+Clazz.defineMethod (c$, "getLastCumuleneAtom", 
+ function (bond, atom, nSP2) {
+var atom2 = bond.getOtherAtomNode (atom);
+if (nSP2 != null) nSP2[0] = 2;
+while (true) {
+if (atom2.getCovalentBondCount () != 2) return atom2;
+var edges = atom2.getEdges ();
+for (var i = edges.length; --i >= 0; ) {
+var atom3 = (bond = edges[i]).getOtherAtomNode (atom2);
+if (atom3 === atom) continue;
+if (bond.getCovalentOrder () != 2) return atom2;
+if (nSP2 != null) nSP2[0]++;
+atom = atom2;
+atom2 = atom3;
+break;
+}
+}
+}, "JU.Edge,JU.Node,~A");
 Clazz.defineMethod (c$, "getAtomChiralityLimited", 
  function (atom, cipAtom, parent, ruleMax) {
 var rs = 0;
@@ -222,7 +244,7 @@ var isAlkene = false;
 try {
 if (cipAtom == null) {
 this.htPathPoints =  new java.util.Hashtable ();
-cipAtom = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null, atom, null, false, isAlkene);
+cipAtom = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null).create (atom, null, false, isAlkene);
 var nSubs = atom.getCovalentBondCount ();
 var elemNo = atom.getElementNumber ();
 isAlkene = (nSubs == 3 && elemNo <= 10);
@@ -260,47 +282,63 @@ if (this.currentRule == 5) cipAtom.isPseudo = cipAtom.canBePseudo;
 if (isChiral) {
 rs = (!isAlkene ? cipAtom.checkHandedness () : cipAtom.atoms[0].isDuplicate ? 2 : 1);
 if (cipAtom.isPseudo && !isAlkene) rs = rs | 4;
-}if (JU.Logger.debugging) JU.Logger.info (atom + " " + rs);
-if (JU.Logger.debugging) JU.Logger.info ("----------------------------------");
+}if (JU.Logger.debugging) JU.Logger.info (atom + " " + rs + "\n----------------------------------");
 }} catch (e) {
 System.out.println (e + " in CIPChirality");
-if (!this.vwr.isJS) e.printStackTrace ();
-return 3;
+{
+alert(e);
+}return 3;
 }
 return rs;
 }, "JU.Node,JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom,~N");
 Clazz.defineMethod (c$, "getBondChiralityLimited", 
- function (bond, ruleMax) {
+ function (bond, a, ruleMax) {
 if (JU.Logger.debugging) JU.Logger.info ("get Bond Chirality " + bond);
-var ez = 0;
-var atoms = this.vwr.ms.at;
-if (bond.getCovalentOrder () == 2) {
-var a = atoms[bond.getAtomIndex1 ()];
-var b = atoms[bond.getAtomIndex2 ()];
-if (!this.couldBeEZ (a, b)) return 0;
+if (a == null) a = bond.getOtherAtomNode (null);
+var b = bond.getOtherAtomNode (a);
+if (this.couldBeChiralAlkene (a, b) == -1) return 0;
+var nSP2 =  Clazz.newIntArray (1, 0);
+b = this.getLastCumuleneAtom (bond, a, nSP2);
+var isCumulene = (nSP2[0] > 2);
+var isAxial = isCumulene && (nSP2[0] % 2 == 1);
+return this.getAxialOrEZChirality (a, b, isAxial, ruleMax);
+}, "JU.Edge,JU.Node,~N");
+Clazz.defineMethod (c$, "getAxialOrEZChirality", 
+ function (a, b, isAxial, ruleMax) {
 this.htPathPoints =  new java.util.Hashtable ();
-var a1 = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null, a, null, false, true);
-var b1 = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null, b, null, false, true);
+var a1 = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null).create (a, null, false, true);
+var b1 = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null).create (b, null, false, true);
+a1.canBePseudo = a1.isOddCumulene = isAxial;
 var atop = this.getAtomChiralityLimited (a, a1, b1, ruleMax) - 1;
 this.htPathPoints =  new java.util.Hashtable ();
-var a2 = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null, a, null, false, true);
-var b2 = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null, b, null, false, true);
+var a2 = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null).create (a, null, false, true);
+var b2 = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null).create (b, null, false, true);
+b2.canBePseudo = b2.isOddCumulene = isAxial;
 var btop = this.getAtomChiralityLimited (b, b2, a2, ruleMax) - 1;
+var c = 0;
 if (atop >= 0 && btop >= 0) {
-ez = (this.isCIS (b2.atoms[btop], b2, a1, a1.atoms[atop]) ? 1 : 2);
-}if (ez != 0) {
-a.setCIPChirality (ez << 3);
-b.setCIPChirality (ez << 3);
-}if (JU.Logger.debugging) JU.Logger.info (bond + " " + (ez == 1 ? "Z" : ez == 2 ? "E" : "_"));
-}return ez;
-}, "JU.Edge,~N");
-Clazz.defineMethod (c$, "isCIS", 
+if (isAxial) {
+c = (this.isPos (b2.atoms[btop], b2, a1, a1.atoms[atop]) ? 34 : 33);
+if ((a2.ties == null) != (b2.ties == null)) c |= 4;
+} else {
+c = (this.isCis (b2.atoms[btop], b2, a1, a1.atoms[atop]) ? 8 : 16);
+}}if (c != 0) {
+a.setCIPChirality (c);
+b.setCIPChirality (c);
+if (JU.Logger.debugging) JU.Logger.info (a + "-" + b + " " + JV.JC.getCIPChiralityName (c));
+}return c;
+}, "JU.Node,JU.Node,~B,~N");
+Clazz.defineMethod (c$, "isCis", 
 function (a, b, c, d) {
 JU.Measure.getNormalThroughPoints (a.atom.getXYZ (), b.atom.getXYZ (), c.atom.getXYZ (), this.vNorm, this.vTemp);
 var vNorm2 =  new JU.V3 ();
 JU.Measure.getNormalThroughPoints (b.atom.getXYZ (), c.atom.getXYZ (), d.atom.getXYZ (), vNorm2, this.vTemp);
 return (this.vNorm.dot (vNorm2) > 0);
 }, "JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom");
+Clazz.defineMethod (c$, "isPos", 
+function (a, b, c, d) {
+return (JU.Measure.computeTorsion (a.atom.getXYZ (), b.atom.getXYZ (), c.atom.getXYZ (), d.atom.getXYZ (), true) > 0);
+}, "JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom");
 Clazz.defineMethod (c$, "sign", 
 function (score) {
 return (score < 0 ? -1 : score > 0 ? 1 : 0);
@@ -327,6 +365,7 @@ this.isSet = false;
 this.isDuplicate = true;
 this.isTerminal = false;
 this.isAlkene = false;
+this.alkeneParent = null;
 this.isAlkeneAtom2 = false;
 this.doCheckPseudo = false;
 this.isPseudo = false;
@@ -342,6 +381,9 @@ this.auxEZ = -1;
 this.auxParentReversed = null;
 this.auxPseudo = null;
 this.canBePseudo = true;
+this.ties = null;
+this.isOddCumulene = false;
+this.nextSP2 = null;
 Clazz.instantialize (this, arguments);
 }, JS.CIPChirality, "CIPAtom", null, [Comparable, Cloneable]);
 Clazz.prepareFields (c$, function () {
@@ -350,10 +392,13 @@ this.priorities =  Clazz.newIntArray (4, 0);
 this.prevPriorities =  Clazz.newIntArray (4, 0);
 });
 Clazz.makeConstructor (c$, 
+function () {
+});
+Clazz.defineMethod (c$, "create", 
 function (a, b, c, d) {
 this.id = ++this.b$["JS.CIPChirality"].ptID;
 this.parent = b;
-if (a == null) return;
+if (a == null) return this;
 this.isAlkene = d;
 this.atom = a;
 this.elemNo = a.getElementNumber ();
@@ -390,6 +435,7 @@ this.b$["JS.CIPChirality"].htPathPoints.put (this.rootSubstituent.atom.toString
 this.myPath = (b != null ? b.myPath + "-" : "") + this;
 if (JU.Logger.debugging) JU.Logger.info ("new CIPAtom " + b + "->" + this);
 if (c && !f) this.updateRingList ();
+return this;
 }, "JU.Node,JS.CIPChirality.CIPAtom,~B,~B");
 Clazz.defineMethod (c$, "getLonePair", 
  function () {
@@ -432,8 +478,13 @@ if (this.elemNo > 10 || !this.b$["JS.CIPChirality"].isFirstRow (f)) h = 1;
  else {
 this.isAlkene = true;
 if (g) {
-this.isAlkeneAtom2 = true;
 this.knownAtomChirality = e.getCIPChirality (false);
+if (this.atom.getCovalentBondCount () == 2 && this.atom.getValence () == 4) {
+this.parent.isAlkeneAtom2 = false;
+} else {
+this.isAlkeneAtom2 = true;
+}this.alkeneParent = (this.parent.alkeneParent == null ? this.parent : this.parent.alkeneParent);
+if (this.parent.alkeneParent == null) this.parent.nextSP2 = this;
 }}}if (a == 1 && h == 1 && g) {
 this.isTerminal = true;
 return true;
@@ -458,7 +509,7 @@ return false;
 }
 this.isTerminal = (c == 0);
 this.nAtoms = c;
-for (; c < this.atoms.length; c++) this.atoms[c] = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null, null, this, true, false);
+for (; c < this.atoms.length; c++) this.atoms[c] = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null).create (null, this, true, false);
 
 var e = this.b$["JS.CIPChirality"].currentRule;
 this.b$["JS.CIPChirality"].currentRule = 1;
@@ -477,7 +528,7 @@ if (e == 1) {
 if (++this.h1Count > 1) {
 if (JU.Logger.debugging) JU.Logger.info (" second H atom found on " + this.atom);
 return null;
-}}}this.atoms[a] = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null, b, this, c, d);
+}}}this.atoms[a] = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null).create (b, this, c, d);
 if (this.b$["JS.CIPChirality"].currentRule > 2) this.prevPriorities[a] = this.getBasePriority (this.atoms[a]);
 return this.atoms[a];
 }, "~N,JU.Node,~B,~B");
@@ -488,84 +539,85 @@ JU.Logger.info (this.b$["JS.CIPChirality"].root + "---sortSubstituents---" + thi
 for (var a = 0; a < 4; a++) {
 JU.Logger.info (this.b$["JS.CIPChirality"].getRuleName () + ": " + this + "[" + a + "]=" + this.atoms[a].myPath + " " + Integer.toHexString (this.prevPriorities[a]));
 }
+JU.Logger.info ("---");
 }var a =  Clazz.newIntArray (4, 0);
-var b = null;
-for (var c = 0; c < 4; c++) {
-this.priorities[c] = 1;
-if (this.prevPriorities[c] == 0 && this.b$["JS.CIPChirality"].currentRule > 1) this.prevPriorities[c] = this.getBasePriority (this.atoms[c]);
+this.ties = null;
+for (var b = 0; b < 4; b++) {
+this.priorities[b] = 1;
+if (this.prevPriorities[b] == 0 && this.b$["JS.CIPChirality"].currentRule > 1) this.prevPriorities[b] = this.getBasePriority (this.atoms[b]);
 }
-var d = (this.b$["JS.CIPChirality"].currentRule > 3 && this.rule4List != null);
-for (var e = 0; e < 4; e++) {
-var f = this.atoms[e];
-for (var g = e + 1; g < 4; g++) {
-var h = this.atoms[g];
-var i = (f.atom == null ? 1 : h.atom == null ? -1 : this.prevPriorities[e] == this.prevPriorities[g] ? 0 : this.prevPriorities[g] < this.prevPriorities[e] ? 1 : -1);
-if (i == 0) i = (d ? this.checkRule4And5 (e, g) : f.compareTo (h));
-if (JU.Logger.debuggingHigh) JU.Logger.info ("ordering " + this.id + "." + e + "." + g + " " + this + "-" + f + " vs " + h + " = " + i);
-switch (i) {
+var c = (this.b$["JS.CIPChirality"].currentRule > 3 && this.rule4List != null);
+for (var d = 0; d < 4; d++) {
+var e = this.atoms[d];
+for (var f = d + 1; f < 4; f++) {
+var g = this.atoms[f];
+var h = (e.atom == null ? 1 : g.atom == null ? -1 : this.prevPriorities[d] == this.prevPriorities[f] ? 0 : this.prevPriorities[f] < this.prevPriorities[d] ? 1 : -1);
+if (h == 0) h = (c ? this.checkRule4And5 (d, f) : e.compareTo (g));
+if (JU.Logger.debuggingHigh) JU.Logger.info ("ordering " + this.id + "." + d + "." + f + " " + this + "-" + e + " vs " + g + " = " + h);
+switch (h) {
 case -2147483648:
-if (d && this.sphere == 0) this.achiral = true;
-a[e]++;
-if (JU.Logger.debuggingHigh) JU.Logger.info (this.atom + "." + h + " ends up with tie with " + f);
+if (c && this.sphere == 0) this.achiral = true;
+a[d]++;
+if (JU.Logger.debuggingHigh) JU.Logger.info (this.atom + "." + g + " ends up with tie with " + e);
 break;
 case 1:
-a[e]++;
-this.priorities[e]++;
-if (JU.Logger.debuggingHigh) JU.Logger.info (this + "." + h + " B-beats " + f);
+a[d]++;
+this.priorities[d]++;
+if (JU.Logger.debuggingHigh) JU.Logger.info (this + "." + g + " B-beats " + e);
 break;
 case -1:
-a[g]++;
-this.priorities[g]++;
-if (JU.Logger.debuggingHigh) JU.Logger.info (this + "." + f + " A-beats " + h);
+a[f]++;
+this.priorities[f]++;
+if (JU.Logger.debuggingHigh) JU.Logger.info (this + "." + e + " A-beats " + g);
 break;
 case 0:
-i = f.breakTie (h);
-switch (this.b$["JS.CIPChirality"].sign (i)) {
+h = e.breakTie (g);
+switch (this.b$["JS.CIPChirality"].sign (h)) {
 case 0:
-a[e]++;
-if (JU.Logger.debuggingHigh) JU.Logger.info (this + "." + h + " ends up with tie with " + f);
+a[d]++;
+if (JU.Logger.debuggingHigh) JU.Logger.info (this + "." + g + " ends up with tie with " + e);
 break;
 case 1:
-a[e]++;
-this.priorities[e]++;
-if (JU.Logger.debuggingHigh) JU.Logger.info (this + "." + h + " wins in tie with " + f);
+a[d]++;
+this.priorities[d]++;
+if (JU.Logger.debuggingHigh) JU.Logger.info (this + "." + g + " wins in tie with " + e);
 break;
 case -1:
-a[g]++;
-this.priorities[g]++;
-if (JU.Logger.debuggingHigh) JU.Logger.info (this + "." + f + " wins in tie with " + h);
+a[f]++;
+this.priorities[f]++;
+if (JU.Logger.debuggingHigh) JU.Logger.info (this + "." + e + " wins in tie with " + g);
 break;
 }
 break;
 }
 if (this.doCheckPseudo) {
 this.doCheckPseudo = false;
-if (b == null) b =  new JU.Lst ();
-b.addLast ( Clazz.newIntArray (-1, [e, g]));
+if (this.ties == null) this.ties =  new JU.Lst ();
+this.ties.addLast ( Clazz.newIntArray (-1, [d, f]));
 }}
 }
-var f =  new Array (4);
+var e =  new Array (4);
+var f =  Clazz.newIntArray (4, 0);
 var g =  Clazz.newIntArray (4, 0);
-var h =  Clazz.newIntArray (4, 0);
-var i =  new JU.BS ();
-var j = JS.CIPChirality.PRIORITY_SHIFT[this.b$["JS.CIPChirality"].currentRule];
-for (var k = 0; k < 4; k++) {
-var l = a[k];
-var m = f[l] = this.atoms[k];
-var n = this.priorities[k];
-g[l] = n;
-h[l] = this.prevPriorities[k] | (n << j);
-if (m.atom != null) i.set (this.priorities[k]);
+var h =  new JU.BS ();
+var i = JS.CIPChirality.PRIORITY_SHIFT[this.b$["JS.CIPChirality"].currentRule];
+for (var j = 0; j < 4; j++) {
+var k = a[j];
+var l = e[k] = this.atoms[j];
+var m = this.priorities[j];
+f[k] = m;
+g[k] = this.prevPriorities[j] | (m << i);
+if (l.atom != null) h.set (this.priorities[j]);
 }
-this.atoms = f;
-this.priorities = g;
-this.prevPriorities = h;
-this.nPriorities = i.cardinality ();
+this.atoms = e;
+this.priorities = f;
+this.prevPriorities = g;
+this.nPriorities = h.cardinality ();
 if (this.nPriorities > this.b$["JS.CIPChirality"].nPriorityMax) this.b$["JS.CIPChirality"].nPriorityMax = this.nPriorities;
-if (b != null) {
-switch (b.size ()) {
+if (this.ties != null && !this.isOddCumulene) {
+switch (this.ties.size ()) {
 case 1:
-this.checkPseudoHandedness (b.get (0), a);
+this.checkPseudoHandedness (this.ties.get (0), a);
 break;
 case 2:
 this.canBePseudo = false;
@@ -573,7 +625,7 @@ break;
 }
 }if (JU.Logger.debugging) {
 JU.Logger.info (this.atom + " nPriorities = " + this.nPriorities);
-for (var l = 0; l < 4; l++) JU.Logger.info (this.myPath + "[" + l + "]=" + this.atoms[l] + " " + this.priorities[l] + " new");
+for (var k = 0; k < 4; k++) JU.Logger.info (this.myPath + "[" + k + "]=" + this.atoms[k] + " " + this.priorities[k] + " new");
 
 JU.Logger.info ("-------");
 }});
@@ -665,30 +717,34 @@ Clazz.defineMethod (c$, "checkRule3",
  function (a) {
 var b;
 var c;
-return this.parent == null || !this.parent.isAlkeneAtom2 || !a.parent.isAlkeneAtom2 || this.isDuplicate || a.isDuplicate ? -2147483648 : this.parent === a.parent ? this.b$["JS.CIPChirality"].sign (this.breakTie (a)) : (b = this.parent.getEZaux ()) < (c = a.parent.getEZaux ()) ? -1 : b > c ? 1 : 0;
+return this.parent == null || !this.parent.isAlkeneAtom2 || !a.parent.isAlkeneAtom2 || this.isDuplicate || a.isDuplicate || !this.isCumulativeType (-2) || !a.isCumulativeType (-2) ? -2147483648 : this.parent === a.parent ? this.b$["JS.CIPChirality"].sign (this.breakTie (a)) : (b = this.parent.getEZaux ()) < (c = a.parent.getEZaux ()) ? -1 : b > c ? 1 : 0;
 }, "JS.CIPChirality.CIPAtom");
+Clazz.defineMethod (c$, "isCumulativeType", 
+ function (a) {
+return (this.parent != null && this.parent.isAlkeneAtom2 && ((this.parent.alkeneParent.sphere + this.parent.sphere) % 2) == (a == -2 ? 1 : 2));
+}, "~N");
 Clazz.defineMethod (c$, "getEZaux", 
  function () {
-if (this.auxEZ == -1 && (this.auxEZ = this.parent.auxEZ) == -1) {
+if (this.auxEZ == -1 && (this.auxEZ = this.alkeneParent.auxEZ) == -1) {
 var a = null;
 var b = null;
 var c = null;
-this.auxEZ = 3;
+this.auxEZ = 24;
 this.sortSubstituents ();
 b = this.getTopAtom ();
 if (b != null) {
 if (this.auxParentReversed == null) {
-if (JU.Logger.debugging) JU.Logger.info ("reversing path for " + this.parent);
-c = this.parent.clone ();
-c.addReturnPath (this, this.parent);
+if (JU.Logger.debugging) JU.Logger.info ("reversing path for " + this.alkeneParent);
+c = this.alkeneParent.clone ();
+c.addReturnPath (this.alkeneParent.nextSP2, this.alkeneParent);
 } else {
 c = this.auxParentReversed;
 }c.sortSubstituents ();
 a = c.getTopAtom ();
 if (a != null) {
-this.auxEZ = (this.b$["JS.CIPChirality"].isCIS (b, this, c, a) ? 1 : 2);
-if (JU.Logger.debugging) JU.Logger.info ("getZaux " + (this.auxEZ == 1 ? "Z" : "E") + " for " + this.atom + "=" + this.parent.atom + " : " + a + " " + b);
-}}}this.parent.auxEZ = this.auxEZ;
+this.auxEZ = (this.b$["JS.CIPChirality"].isCis (b, this, c, a) ? 8 : 16);
+}}}this.alkeneParent.auxEZ = this.auxEZ;
+if (JU.Logger.debugging) JU.Logger.info ("getZaux " + this.alkeneParent + " " + this.auxEZ);
 return this.auxEZ;
 });
 Clazz.defineMethod (c$, "getReturnPath", 
@@ -708,7 +764,7 @@ var d = this;
 for (var e = 0, f = c.size (); e < f; e++) {
 var g = c.get (e);
 if (g == null) {
-g = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null, null, this, true, this.isAlkene);
+g = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null).create (null, this, true, this.isAlkene);
 } else {
 var h = g.sphere;
 g = g.clone ();
@@ -940,7 +996,6 @@ b = j.checkHandedness ();
 d = (b == 1 ? "R" : b == 2 ? "S" : "~");
 if (i != 0) d = d.toLowerCase ();
 }}}d += c;
-System.out.println (this + " creating aux " + d);
 return d;
 }, "~B");
 Clazz.defineMethod (c$, "compareRule4aEnantiomers", 
@@ -965,8 +1020,8 @@ var d = a[1];
 var e;
 if (this.auxPseudo == null) {
 e = this.clone ();
-e.atoms[b[c]] = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null, null, e, false, this.isAlkene);
-e.atoms[b[d]] = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null, null, e, false, this.isAlkene);
+e.atoms[b[c]] = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null).create (null, e, false, this.isAlkene);
+e.atoms[b[d]] = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null).create (null, e, false, this.isAlkene);
 e.addReturnPath (null, this);
 } else {
 e = this.auxPseudo;
@@ -1007,7 +1062,7 @@ this.atoms[c] = b;
 if (JU.Logger.debugging) JU.Logger.info ("replace " + this + "[" + c + "]=" + b);
 this.prevPriorities[c] = this.getBasePriority (this.atoms[c]);
 this.parent = a;
-break;
+return;
 }
 }, "JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom");
 Clazz.defineMethod (c$, "getTopAtom", 
@@ -1075,11 +1130,17 @@ Clazz.defineStatics (c$,
 "NOT_RELEVANT", -2147483648,
 "STEREO_SAME", 2147483647,
 "STEREO_UNDETERMINED", -1,
-"STEREO_BOTH", 3,
+"STEREO_RS", -1,
+"STEREO_EZ", -2,
+"STEREO_ALLENE", -3,
 "STEREO_R", 1,
 "STEREO_S", 2,
-"STEREO_Z", 1,
-"STEREO_E", 2,
+"STEREO_M", 33,
+"STEREO_P", 34,
+"STEREO_Z", 8,
+"STEREO_E", 16,
+"STEREO_BOTH_RS", 3,
+"STEREO_BOTH_EZ", 24,
 "RULE_0", 0,
 "RULE_1", 1,
 "RULE_2", 2,
