@@ -493,10 +493,11 @@ return cip.getBondChirality (bond);
 Clazz.overrideMethod (c$, "calculateCIPChiralityForAtoms", 
 function (vwr, bsAtoms) {
 var cip = this.getCIPChirality (vwr);
-cip.getChiralityForAtoms (vwr.ms.at, bsAtoms);
+var bsAtropisomer = vwr.getAtomBitSet ("smarts('a-a')");
+cip.getChiralityForAtoms (vwr.ms.at, bsAtoms, bsAtropisomer);
 }, "JV.Viewer,JU.BS");
 Clazz.defineMethod (c$, "getCIPChirality", 
  function (vwr) {
-return (this.cip == null ? (this.cip = (J.api.Interface.getInterface ("JS.CIPChirality", vwr, "script"))).setViewer (vwr) : this.cip);
+return (this.cip == null ? (this.cip = (J.api.Interface.getInterface ("JS.CIPChirality", vwr, "script"))) : this.cip);
 }, "JV.Viewer");
 });
