@@ -28,7 +28,7 @@ function(a){var b=(new JU.SB).append("\n# label defaults;\n");this.app(b,"select
 this.app(b,"set labelPointer "+(0==c.length?"off":c));0!=(a.defaultZPos&32)?this.app(b,"set labelFront"):0!=(a.defaultZPos&16)&&this.app(b,"set labelGroup");this.app(b,J.shape.Shape.getFontCommand("label",javajs.awt.Font.getFont3D(a.defaultFontId)));return b.toString()},"J.shape.Labels");h(c$,"getSelectionState",function(a,b){var c=new JU.SB;null!=b&&(b.append("  _setSelectionState;\n"),c.append("function _setSelectionState() {\n"));null!=this.vwr.ms.trajectory&&this.app(c,this.vwr.ms.trajectory.getState());
 var d=new java.util.Hashtable,e=null;this.addBs(c,"hide ",a.bsHidden);this.addBs(c,"subset ",a.bsSubset);this.addBs(c,"delete ",a.bsDeleted);this.addBs(c,"fix ",a.bsFixed);d.put("-",this.vwr.slm.getSelectedAtomsNoSubset());e=this.getCommands(d,null,"select");null==e?this.app(c,"select none"):c.append(e);this.app(c,"set hideNotSelected "+a.hideNotSelected);c.append(this.vwr.getShapeProperty(1,"selectionState"));this.vwr.getSelectionHalosEnabled()&&this.app(c,"SelectionHalos ON");null!=b&&c.append("}\n\n");
 return c.toString()},"JV.SelectionManager,JU.SB");h(c$,"getViewState",function(a,b){var c=new JU.SB,d=a.getMoveToText(0,!1);null!=b&&(b.append("  _setPerspectiveState;\n"),c.append("function _setPerspectiveState() {\n"));this.app(c,"set perspectiveModel "+a.perspectiveModel);this.app(c,"set scaleAngstromsPerInch "+a.scale3DAngstromsPerInch);this.app(c,"set perspectiveDepth "+a.perspectiveDepth);this.app(c,"set visualRange "+a.visualRangeAngstroms);a.isWindowCentered()||this.app(c,"set windowCentered false");
-this.app(c,"set cameraDepth "+a.cameraDepth);var e=1==a.mode;e&&this.app(c,"set navigationMode true");this.app(c,this.vwr.ms.getBoundBoxCommand(!1));this.app(c,"center "+JU.Escape.eP(a.fixedRotationCenter));c.append(this.vwr.getOrientationText(1073742035,null));this.app(c,d);!e&&!a.zoomEnabled&&this.app(c,"zoom off");c.append("  slab ").appendI(a.slabPercentSetting).append(";depth ").appendI(a.depthPercentSetting).append(a.slabEnabled&&!e?";slab on":"").append(";\n");c.append("  set slabRange ").appendF(a.slabRange).append(";\n");
+this.app(c,"set cameraDepth "+a.cameraDepth);var e=1==a.mode;e&&this.app(c,"set navigationMode true");this.app(c,this.vwr.ms.getBoundBoxCommand(!1));this.app(c,"center "+JU.Escape.eP(a.fixedRotationCenter));c.append(this.vwr.getOrientationText(1073742034,null));this.app(c,d);!e&&!a.zoomEnabled&&this.app(c,"zoom off");c.append("  slab ").appendI(a.slabPercentSetting).append(";depth ").appendI(a.depthPercentSetting).append(a.slabEnabled&&!e?";slab on":"").append(";\n");c.append("  set slabRange ").appendF(a.slabRange).append(";\n");
 null!=a.slabPlane&&c.append("  slab plane ").append(JU.Escape.eP4(a.slabPlane)).append(";\n");null!=a.depthPlane&&c.append("  depth plane ").append(JU.Escape.eP4(a.depthPlane)).append(";\n");this.getZshadeState(c,a,!1);c.append(this.getSpinState(!0)).append("\n");this.vwr.ms.modelSetHasVibrationVectors()&&a.vibrationOn&&this.app(c,"set vibrationPeriod "+a.vibrationPeriod+";vibration on");d=null!=a.depthPlane||null!=a.slabPlane;e&&c.append(a.getNavigationState());!a.slabEnabled&&d&&c.append("  slab off;\n");
 null!=b&&c.append("}\n\n");return c.toString()},"JV.TransformManager,JU.SB");h(c$,"getZshadeState",function(a,b,c){c&&(this.app(a,"set zDepth "+b.zDepthPercentSetting),this.app(a,"set zSlab "+b.zSlabPercentSetting),b.zShadeEnabled||this.app(a,"set zShade false"));b.zShadeEnabled&&this.app(a,"set zShade true");try{null!=b.zSlabPoint&&this.app(a,"set zSlab "+JU.Escape.eP(b.zSlabPoint))}catch(d){if(!s(d,Exception))throw d;}},"JU.SB,JV.TransformManager,~B");l(c$,"getSpinState",function(){var a=this.vwr.tm,
 b="  set spinX "+p(a.spinX)+"; set spinY "+p(a.spinY)+"; set spinZ "+p(a.spinZ)+"; set spinFps "+p(a.spinFps)+";";Float.isNaN(a.navFps)||(b+="  set navX "+p(a.navX)+"; set navY "+p(a.navY)+"; set navZ "+p(a.navZ)+"; set navFps "+p(a.navFps)+";");a.navOn&&(b+=" navigation on;");if(!a.spinOn)return b;var c=a.isSpinSelected?"\n  select "+JU.Escape.eBS(this.vwr.bsA())+";\n  rotateSelected":"\n ";if(a.isSpinInternal){var d=JU.P3.newP(a.internalRotationCenter);d.sub(a.rotationAxis);b+=c+" spin "+a.rotationRate+
@@ -55,13 +55,13 @@ c.z?" %":"").append("];\n");c=a.labels;if(null!=c){b.append("  axes labels ");fo
 e,e,b+" "+(0>(d=a.mads[e])?c&&-1>d?""+-d:"on":JU.PT.escF(d/2E3)));if(null!=a.bsColixSet)for(e=a.bsColixSet.nextSetBit(0);0<=e;e=a.bsColixSet.nextSetBit(e+1))JU.BSUtil.setMapBitSet(this.temp2,e,e,J.shape.Shape.getColorCommand(b,a.paletteIDs[e],a.colixes[e],a.translucentAllowed));a=this.getCommands(this.temp,this.temp2,"select");this.clearTemp();return a},"J.shape.AtomShape");h(c$,"getTextState",function(a){var b=new JU.SB,c=a.text;if(null==c||a.isLabelOrHover||a.target.equals("error"))return"";var d=
 null!=a.image,e=null,f="set echo ID "+JU.PT.esc(a.target);switch(a.valign){case 3:e=2147483647==a.movableXPercent||2147483647==a.movableYPercent?(2147483647==a.movableXPercent?a.movableX+" ":a.movableXPercent+"% ")+(2147483647==a.movableYPercent?a.movableY+"":a.movableYPercent+"%"):"["+a.movableXPercent+" "+a.movableYPercent+"%]";case 4:null==e&&(e=JU.Escape.eP(a.xyz));b.append("  ").append(f).append(" ").append(e);4!=a.align&&b.append(";  ").append(f).append(" ").append(JV.JC.getHorizAlignmentName(a.align));
 break;default:b.append("  set echo ").append(JV.JC.getEchoName(a.valign)).append(" ").append(JV.JC.getHorizAlignmentName(a.align))}2147483647!=a.movableZPercent&&b.append(";  ").append(f).append(" depth ").appendI(a.movableZPercent);d?b.append("; ").append(f).append(" IMAGE /*file*/"):b.append("; echo ");b.append(JU.PT.esc(c));b.append(";\n");d&&1!=a.imageScale&&b.append("  ").append(f).append(" scale ").appendF(a.imageScale).append(";\n");null!=a.script&&b.append("  ").append(f).append(" script ").append(JU.PT.esc(a.script)).append(";\n");
-0<=a.modelIndex&&b.append("  ").append(f).append(" model ").append(this.vwr.getModelNumberDotted(a.modelIndex)).append(";\n");null!=a.pointerPt&&b.append("  ").append(f).append(" point ").append(r(a.pointerPt,JM.Atom)?"({"+a.pointerPt.i+"})":JU.Escape.eP(a.pointerPt)).append(";\n");a.appendFontCmd(b);b.append("; color echo");JU.C.isColixTranslucent(a.colix)&&b.append(JU.C.getColixTranslucencyLabel(a.colix));b.append(" ").append(JU.C.getHexCode(a.colix));0!=a.bgcolix&&(b.append("; color echo background "),
-JU.C.isColixTranslucent(a.bgcolix)&&b.append(JU.C.getColixTranslucencyLabel(a.bgcolix)).append(" "),b.append(JU.C.getHexCode(a.bgcolix)));b.append(";\n");return b.toString()},"JM.Text");l(c$,"getAllSettings",function(a){for(var b=this.vwr.g,c=new JU.SB,d=Array(b.htBooleanParameterFlags.size()+b.htNonbooleanParameterValues.size()+b.htUserVariables.size()),e=0,f="_"+a,g,k=b.htBooleanParameterFlags.keySet().iterator();k.hasNext()&&((g=k.next())||1);)if(null==a||0==g.indexOf(a)||0==g.indexOf(f))d[e++]=
-(0==g.indexOf("_")?g+" = ":"set "+g+" ")+b.htBooleanParameterFlags.get(g);for(k=b.htNonbooleanParameterValues.keySet().iterator();k.hasNext()&&((g=k.next())||1);)if("@"!=g.charAt(0)&&(null==a||0==g.indexOf(a)||0==g.indexOf(f))){var h=b.htNonbooleanParameterValues.get(g);r(h,String)&&(h=JV.StateCreator.chop(JU.PT.esc(h)));d[e++]=(0==g.indexOf("_")?g+" = ":"set "+g+" ")+h}for(k=b.htUserVariables.keySet().iterator();k.hasNext()&&((g=k.next())||1);)if(null==a||0==g.indexOf(a))h=b.htUserVariables.get(g),
-f=h.escape(),d[e++]=g+" "+(g.startsWith("@")?"":"= ")+(4==h.tok?JV.StateCreator.chop(JU.PT.esc(f)):f);java.util.Arrays.sort(d,0,e);for(a=0;a<e;a++)null!=d[a]&&this.app(c,d[a]);c.append("\n");return c.toString()},"~S");c$.chop=h(c$,"chop",function(a){var b=a.length;if(512>b)return a;for(var c=new JU.SB,d=0,e=72;e<b;d=e,e+=72){for(;"\\"==a.charAt(e-1);)e++;c.append(0==d?"":'"\\\n    + "').append(a.substring(d,e))}c.append('"\\\n    + "').append(a.substring(d,b));return c.toString()},"~S");l(c$,"getFunctionCalls",
-function(a){null==a&&(a="");var b=new JU.SB,c=a.indexOf("*"),d=0<=c,e=0==a.indexOf("static_"),f=a.equalsIgnoreCase("names")||a.equalsIgnoreCase("static_names");f&&(a="");d&&(a=a.substring(0,c));a=a.toLowerCase();(e||0==a.length)&&this.addFunctions(b,JV.Viewer.staticFunctions,a,d,f);(!e||0==a.length)&&this.addFunctions(b,this.vwr.localFunctions,a,d,f);return b.toString()},"~S");h(c$,"addFunctions",function(a,b,c,d,e){for(var f=Array(b.size()),g=0,k,h=b.keySet().iterator();h.hasNext()&&((k=h.next())||
-1);)if(0==c.length&&!k.startsWith("_")||k.equalsIgnoreCase(c)||d&&0==k.toLowerCase().indexOf(c))f[g++]=k;java.util.Arrays.sort(f,0,g);for(c=0;c<g;c++)d=b.get(f[c]),a.append(e?d.getSignature():d.toString()),a.appendC("\n")},"JU.SB,java.util.Map,~S,~B,~B");c$.isTainted=h(c$,"isTainted",function(a,b,c){return null!=a&&null!=a[c]&&a[c].get(b)},"~A,~N,~N");l(c$,"getAtomicPropertyState",function(a,b){if(!this.vwr.g.preserveState)return"";for(var c,d=new JU.SB,e=0;17>e;e++)if(0>a||e==a)null!=(c=null!=b?
-b:this.vwr.ms.getTaintedAtoms(e))&&this.getAtomicPropertyStateBuffer(d,e,c,null,null);return d.toString()},"~N,JU.BS");l(c$,"getAtomicPropertyStateBuffer",function(a,b,c,d,e){if(this.vwr.g.preserveState){var f=new JU.SB;d=(null==d?JM.AtomCollection.userSettableValues[b]:d)+" set";var g=0,k=2==b,h=this.vwr.ms.at,m=this.vwr.ms.tainted;if(null!=c)for(var j=c.nextSetBit(0);0<=j;j=c.nextSetBit(j+1))if(!h[j].isDeleted()){f.appendI(j+1).append(" ").append(h[j].getElementSymbol()).append(" ").append(h[j].getInfo().$replace(" ",
+0<=a.modelIndex&&b.append("  ").append(f).append(" model ").append(this.vwr.getModelNumberDotted(a.modelIndex)).append(";\n");null!=a.pointerPt&&b.append("  ").append(f).append(" point ").append(r(a.pointerPt,JM.Atom)?"({"+a.pointerPt.i+"})":JU.Escape.eP(a.pointerPt)).append(";\n");null!=a.pymolOffset&&b.append("  ").append(f).append(" offset ").append(JU.Escape.escapeFloatA(a.pymolOffset,!0)).append(";\n");a.appendFontCmd(b);b.append("; color echo");JU.C.isColixTranslucent(a.colix)&&b.append(JU.C.getColixTranslucencyLabel(a.colix));
+b.append(" ").append(JU.C.getHexCode(a.colix));0!=a.bgcolix&&(b.append("; color echo background "),JU.C.isColixTranslucent(a.bgcolix)&&b.append(JU.C.getColixTranslucencyLabel(a.bgcolix)).append(" "),b.append(JU.C.getHexCode(a.bgcolix)));b.append(";\n");return b.toString()},"JM.Text");l(c$,"getAllSettings",function(a){for(var b=this.vwr.g,c=new JU.SB,d=Array(b.htBooleanParameterFlags.size()+b.htNonbooleanParameterValues.size()+b.htUserVariables.size()),e=0,f="_"+a,g,k=b.htBooleanParameterFlags.keySet().iterator();k.hasNext()&&
+((g=k.next())||1);)if(null==a||0==g.indexOf(a)||0==g.indexOf(f))d[e++]=(0==g.indexOf("_")?g+" = ":"set "+g+" ")+b.htBooleanParameterFlags.get(g);for(k=b.htNonbooleanParameterValues.keySet().iterator();k.hasNext()&&((g=k.next())||1);)if("@"!=g.charAt(0)&&(null==a||0==g.indexOf(a)||0==g.indexOf(f))){var h=b.htNonbooleanParameterValues.get(g);r(h,String)&&(h=JV.StateCreator.chop(JU.PT.esc(h)));d[e++]=(0==g.indexOf("_")?g+" = ":"set "+g+" ")+h}for(k=b.htUserVariables.keySet().iterator();k.hasNext()&&
+((g=k.next())||1);)if(null==a||0==g.indexOf(a))h=b.htUserVariables.get(g),f=h.escape(),d[e++]=g+" "+(g.startsWith("@")?"":"= ")+(4==h.tok?JV.StateCreator.chop(JU.PT.esc(f)):f);java.util.Arrays.sort(d,0,e);for(a=0;a<e;a++)null!=d[a]&&this.app(c,d[a]);c.append("\n");return c.toString()},"~S");c$.chop=h(c$,"chop",function(a){var b=a.length;if(512>b)return a;for(var c=new JU.SB,d=0,e=72;e<b;d=e,e+=72){for(;"\\"==a.charAt(e-1);)e++;c.append(0==d?"":'"\\\n    + "').append(a.substring(d,e))}c.append('"\\\n    + "').append(a.substring(d,
+b));return c.toString()},"~S");l(c$,"getFunctionCalls",function(a){null==a&&(a="");var b=new JU.SB,c=a.indexOf("*"),d=0<=c,e=0==a.indexOf("static_"),f=a.equalsIgnoreCase("names")||a.equalsIgnoreCase("static_names");f&&(a="");d&&(a=a.substring(0,c));a=a.toLowerCase();(e||0==a.length)&&this.addFunctions(b,JV.Viewer.staticFunctions,a,d,f);(!e||0==a.length)&&this.addFunctions(b,this.vwr.localFunctions,a,d,f);return b.toString()},"~S");h(c$,"addFunctions",function(a,b,c,d,e){for(var f=Array(b.size()),
+g=0,k,h=b.keySet().iterator();h.hasNext()&&((k=h.next())||1);)if(0==c.length&&!k.startsWith("_")||k.equalsIgnoreCase(c)||d&&0==k.toLowerCase().indexOf(c))f[g++]=k;java.util.Arrays.sort(f,0,g);for(c=0;c<g;c++)d=b.get(f[c]),a.append(e?d.getSignature():d.toString()),a.appendC("\n")},"JU.SB,java.util.Map,~S,~B,~B");c$.isTainted=h(c$,"isTainted",function(a,b,c){return null!=a&&null!=a[c]&&a[c].get(b)},"~A,~N,~N");l(c$,"getAtomicPropertyState",function(a,b){if(!this.vwr.g.preserveState)return"";for(var c,
+d=new JU.SB,e=0;17>e;e++)if(0>a||e==a)null!=(c=null!=b?b:this.vwr.ms.getTaintedAtoms(e))&&this.getAtomicPropertyStateBuffer(d,e,c,null,null);return d.toString()},"~N,JU.BS");l(c$,"getAtomicPropertyStateBuffer",function(a,b,c,d,e){if(this.vwr.g.preserveState){var f=new JU.SB;d=(null==d?JM.AtomCollection.userSettableValues[b]:d)+" set";var g=0,k=2==b,h=this.vwr.ms.at,m=this.vwr.ms.tainted;if(null!=c)for(var j=c.nextSetBit(0);0<=j;j=c.nextSetBit(j+1))if(!h[j].isDeleted()){f.appendI(j+1).append(" ").append(h[j].getElementSymbol()).append(" ").append(h[j].getInfo().$replace(" ",
 "_")).append(" ");switch(b){case 17:j<e.length&&f.appendF(e[j]);break;case 13:f.appendI(h[j].getAtomNumber());break;case 16:f.append(h[j].getChainIDStr());break;case 15:f.appendI(h[j].group.getResno());break;case 14:f.appendI(h[j].getSeqID());break;case 0:f.append(h[j].getAtomName());break;case 1:f.append(h[j].getAtomType());break;case 2:JV.StateCreator.isTainted(m,j,2)&&(k=!1);f.appendF(h[j].x).append(" ").appendF(h[j].y).append(" ").appendF(h[j].z);break;case 12:var l=h[j].getVibrationVector();
 null==l?f.append("0 0 0"):Float.isNaN(l.modScale)?f.appendF(l.x).append(" ").appendF(l.y).append(" ").appendF(l.z):f.appendF(1.4E-45).append(" ").appendF(1.4E-45).append(" ").appendF(l.modScale);break;case 3:f.appendI(h[j].getAtomicAndIsotopeNumber());break;case 4:f.appendI(h[j].getFormalCharge());break;case 6:f.appendF(h[j].getBondingRadius());break;case 7:f.appendI(h[j].getOccupancy100());break;case 8:f.appendF(h[j].getPartialCharge());break;case 9:f.appendF(h[j].getBfactor100()/100);break;case 10:f.appendI(h[j].getValence());
 break;case 11:f.appendF(h[j].getVanderwaalsRadiusFloat(this.vwr,J.c.VDW.AUTO))}f.append(" ;\n");++g}0!=g&&(k&&(d+="(default)"),a.append('\n  DATA "'+d+'"\n').appendI(g).append(" ;\nJmol Property Data Format 1 -- Jmol ").append(JV.Viewer.getJmolVersion()).append(";\n"),a.appendSB(f),a.append('  end "'+d+'";\n'))}},"JU.SB,~N,JU.BS,~S,~A");l(c$,"undoMoveAction",function(a,b){switch(a){case 4165:case 4139:switch(b){case -2:this.vwr.undoClear();break;case -1:(4165==a?this.vwr.actionStates:this.vwr.actionStatesRedo).clear();
